@@ -66,7 +66,7 @@ class PythonHandler(BaseHandler):
     domain: str = "py"  # to match Sphinx's default domain
     enable_inventory: bool = True
     fallback_theme = "material"
-    fallback_config: ClassVar[dict] = {"fallback": True}  # type: ignore[misc]
+    fallback_config: ClassVar[dict] = {"fallback": True}
     default_config: ClassVar[dict] = {
         "docstring_style": "google",
         "docstring_options": {},
@@ -352,6 +352,7 @@ class PythonHandler(BaseHandler):
         self.env.filters["order_members"] = rendering.do_order_members
         self.env.filters["format_code"] = rendering.do_format_code
         self.env.filters["format_signature"] = rendering.do_format_signature
+        self.env.filters["format_attribute"] = rendering.do_format_attribute
         self.env.filters["filter_objects"] = rendering.do_filter_objects
         self.env.filters["stash_crossref"] = lambda ref, length: ref
         self.env.filters["get_template"] = rendering.do_get_template
